# tello_zune
Library used by the Zune Drones team to control the DJI Tello drone. In the examples folder, there are some simple usage examples of the tello_zune module, which is also present in the folder.


To create the library, adaptations were made from two other existing libraries:
* [fvilmos](https://github.com/fvilmos/tello_object_tracking)
* [damiafuentes](https://github.com/damiafuentes/DJITelloPy)

# Requeriments

* Python >= 3.9.0

```bash
pip install numpy
```

```bash
pip install opencv-python
```

# How to use

To use the library, install with:

```bash
pip install tello-zune
```
